@@ -66,10 +66,10 @@ def __getCSV__(requestString, httpClient, gw=True):
         result = get_http_result(httpClient, requestString, gw)
         if result.status_code == 400:
             raise Exception('请检查输入参数，可能某列表输入参数过长')
-        if int(result.headers.get('dyes-rsp-count', 0)) == 100000:
-            result2 = get_http_result(httpClient, requestString + '&pagenum=2', gw)
-            if int(result2.headers.get('dyes-rsp-count', 0)) > 0:
-                raise Exception(get_real_string('Data API查询返回结果超过数据记录上限（十万条记录），请修改查询条件分步查询'))
+        # if int(result.headers.get('dyes-rsp-count', 0)) == 100000:
+        #     result2 = get_http_result(httpClient, requestString + '&pagenum=2', gw)
+        #     if int(result2.headers.get('dyes-rsp-count', 0)) > 0:
+        #         raise Exception(get_real_string('Data API查询返回结果超过数据记录上限（十万条记录），请修改查询条件分步查询'))
         return result.text
     except ReadTimeout:
         raise Exception('查询服务超时')
@@ -100,7 +100,7 @@ def is_no_data_warn(csvString, print_msg):
 
 def handle_error(csvString, api_name):
     if csvString.startswith('-403:Need Privilege'):
-        result = '无%s接口使用权限，您可以购买优矿专业版（https://uqer.io/pro） 或联系 4000 820 386 购买数据' % api_name
+        result = '无%s接口使用权限，您可以购买优矿专业版（https://uqer.datayes.com/pro） 或联系 4000 820 386 购买数据' % api_name
     elif csvString.startswith('-403:Need login'):
         result = '您未登陆'
     elif csvString.startswith('-2:Invalid Request Parameter'):
@@ -251,7 +251,7 @@ def get_api_file(filename):
 def replace_api_files():
     dir_path = os.path.dirname(os.path.realpath(__file__))
     remote_version, py_files = get_api_version()
-    if not remote_version or remote_version <= dataapi_version:
+    if not remote_version or int(remote_version.replace('.', '')) <= int(dataapi_version.replace('.', '')):
         return
 
     for filename in py_files:
@@ -277,4 +277,4 @@ def replace_api_files():
     version_file_path = os.path.join(dir_path, 'version.py')
     with open(version_file_path, 'w') as f:
         f.write(version_str)
-        format_print('UQER SDK的DataAPI模块版本由%s升级到%s'%(dataapi_version, remote_version))
\ No newline at end of file
+        format_print('UQER SDK的DataAPI模块版本由%s升级到%s'%(dataapi_version, remote_version))
