@@ -78,7 +78,7 @@ def portfolio_construction(factor_value_frame, construct_method, start_date, end
                            asset_group_lower_boundary=None, asset_group_upper_boundary=None,
                            factor_exposure_lower_boundary=-10, factor_exposure_upper_boundary=10,
                            sector_exposure_lower_boundary=-10, sector_exposure_upper_boundary=10,
-                           risk_aversion=0, soft_params=None, **kwargs):
+                           risk_aversion=0, soft_params=None, risk_model_version='dy_cne5_old', **kwargs):
     """
     :param factor_value_frame:DataFrame of factor value，因子数据，
                     需包含三列: date(str), ticker(str), value(float)
@@ -116,6 +116,7 @@ def portfolio_construction(factor_value_frame, construct_method, start_date, end
     :param asset_group_upper_boundary: 分组资产权重总和约束上界, dict, key为调仓日期，value为list of Series
     :param risk_aversion: float,风险厌恶系数, >= 0，如果不传则默认为0
     :param soft_params: pd.DataFrame, 软约束参数
+    :param risk_model_version: str, 可以选择不同的风险模型作为组合优化的约束依据
     :return: dict
     """
     if asset_group_lower_boundary is None:
@@ -143,6 +144,9 @@ def portfolio_construction(factor_value_frame, construct_method, start_date, end
             and print_validate_risk_aversion(risk_aversion)
             and print_validate_soft_params(soft_params)):
         return
+    if not (print_valid_sector_exposure(sector_exposure_lower_boundary, risk_model_version)
+            and print_valid_sector_exposure(sector_exposure_upper_boundary, risk_model_version)):
+        return
     if type(universe) in (type(u''), type(b'')):
         if not print_validate_universe(universe):
             return
@@ -163,6 +167,10 @@ def portfolio_construction(factor_value_frame, construct_method, start_date, end
     factor_exposure_upper_boundary = factor_exposure_upper_boundary.to_json() \
         if isinstance(factor_exposure_upper_boundary, pd.Series) \
         else factor_exposure_upper_boundary
+
+    # 替换risk_model输入行业 SW21/SW14
+    sector_exposure_lower_boundary = replace_industry_name(sector_exposure_lower_boundary, risk_model_version)
+    sector_exposure_upper_boundary = replace_industry_name(sector_exposure_upper_boundary, risk_model_version)
     sector_exposure_lower_boundary = sector_exposure_lower_boundary.to_json() \
         if isinstance(sector_exposure_lower_boundary, pd.Series) \
         else sector_exposure_lower_boundary
@@ -173,9 +181,9 @@ def portfolio_construction(factor_value_frame, construct_method, start_date, end
     if init_holding is not None:
         init_holding = init_holding.to_dict() if isinstance(
             init_holding, pd.Series) else init_holding
-    asset_group_lower_boundary_list_dict = {k: [g.to_json() for g in v]
+    asset_group_lower_boundary_list_dict = {str(k)[:10].replace('-', ''): [g.to_json() for g in v]
                                             for k, v in asset_group_lower_boundary.items()}
-    asset_group_upper_boundary_list_dict = {k: [g.to_json() for g in v]
+    asset_group_upper_boundary_list_dict = {str(k)[:10].replace('-', ''): [g.to_json() for g in v]
                                             for k, v in asset_group_upper_boundary.items()}
     opt_params = {
         'set_soft': True if soft_params else False,
@@ -238,6 +246,7 @@ def portfolio_construction(factor_value_frame, construct_method, start_date, end
         "sector_exposure_upper_boundary": sector_exposure_upper_boundary,
         "price_type": price_type,
         'risk_model_type': risk_model_type,
+        'risk_model_version': risk_model_version,
         'opt_params': opt_params,
         "asset_group_lower_boundary_list_dict": asset_group_lower_boundary_list_dict,
         "asset_group_upper_boundary_list_dict": asset_group_upper_boundary_list_dict,
