@@ -63,7 +63,7 @@ update = URL_TEMPLATE.update(
     }
 )
 
-SDK_STATIC_URL = 'http://uqer.io/pro/download/sdk/uqer_sdk.zip'
+SDK_STATIC_URL = 'http://uqer.datayes.com/pro/download/sdk/uqer_sdk.zip'
 
 
 ### Live Trading
